#!/usr/bin/python
import os
import numpy as np

# Minimal lattice constant in A (from run script)
aMin = 5.26
# Maximal lattice constant in A (from run script)
aMax = 5.58
# Sampling density in A (from run script)
step = 0.04
# Number of calculations
n = int(np.rint((aMax - aMin)/step)) + 1

data = open("free_energies.dat",'w')
data.write("#%18s  %18s\n" % ("V (AA^3)","free energy (eV)"))

for i in range(n):
   aLat = aMin + step * i
   print("Postprocessing lattice constant %10.6f AA." % aLat)
   dirname = str(aLat)
   filename = dirname + "/" + "aims.out"
   filename2 = dirname + "/" + "thermal_properties.yaml"
   # Check if calculation was running
   if (not os.path.isfile(filename)):
      print("%s was not processed." % filename)
   else:
      # Check for convergence
      f = open(filename,'r')
      converged = False
      for line in f:
         if "Have a nice day" in line:
            converged = True
         if "Self-consistency cycle converged." in line:
            converged = True
      f.close()

      if (not converged):
         print("%s is not converged." % filename)
      else:
         # Grep for total energy
         f = open(filename,'r')
         for line in f:
            if "Total energy corr" in line:
               linesplit = line.split()
               energy = float(linesplit[5])
         f.close()
         # Grep Vibrational Free energy
         f2 = open(filename2,'r')
         for line in f2:
            if "zero_point_energy:" in line:
               linesplit = line.split()
               free_energy = float(linesplit[1])/96.0+energy
         f2.close()
         Vol=float(aLat)**3/4.0
         data.write(" %14.6f   %14.6f\n" % (Vol,free_energy))
data.close()
