#!/usr/bin/python
import os
import shutil
import numpy as np

# Enter your calculated value for the minimal lattice constant 
aMin = 5.26
# Enter your calculated value for the maximal lattice constant
aMax = 5.58
# Enter a value for the stepwidth
step = 0.04
# Number of calculations
n = int(np.rint((aMax - aMin)/step)) + 1

for i in range(n):
 aLat = aMin + step * i
 print("Processing lattice constant %10.6f AA." % aLat)
 # Create directory
 dirname = str(aLat)
 if not os.path.exists(dirname):
   os.makedirs(dirname)
   # Change to directory        
   os.chdir(dirname)

   # Write geometry.in
   filename = "geometry.in"
   f = open(filename,'w')
   # The lattice
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.0,     0.5*aLat, 0.5*aLat))
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.5*aLat, 0.0,     0.5*aLat))
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.5*aLat, 0.5*aLat, 0.0))
   # The atoms
   f.write("%-14s %10.6f %10.6f %10.6f %2s\n" 
         % ("atom_frac",0.00, 0.00, 0.00,"Si"))
   f.write("%-14s %10.6f %10.6f %10.6f %2s\n" 
         % ("atom_frac",0.25, 0.25, 0.25,"Si"))
   # Close file
   f.close()

   # Copy the control file
   shutil.copyfile("../control.in","control.in")
   shutil.copyfile("../control_s.in","control_s.in")
   shutil.copyfile("../phonopy_disp.conf","phonopy_disp.conf")
   shutil.copyfile("../thermal_properties.conf","thermal_properties.conf")

   # Generate the FORCE_SETS 
   os.system("phonopy -d phonopy_disp.conf --aims")
   subdirname=str("D-001")
   os.makedirs(subdirname)
   os.chdir(subdirname)
   shutil.copyfile("../control_s.in","control.in")
   shutil.copyfile("../geometry.in-001","geometry.in")
   print("Computing the FORCE_SETS (This will take a few minutes) ...")
   os.system("mpirun -n 8 aims.x > D-001.out")
   os.chdir("..")
   os.system("phonopy -f D-001/D-001.out --aims")
   
   # Compute the thermal properties to get the vibrational Free energy
   os.system("phonopy thermal_properties.conf  --aims")

   # Run FHI-aims on to get the total energy 
   os.system("mpirun -n 8 aims.x > aims.out")

   # Change back to former directory
   os.chdir("..")
